@@ -117,7 +117,7 @@ sub _initialize {
     no strict qw(refs);
     $parser->setHandlers(
         Start => sub {
-            # my ($parser, $element, %_attrs) = @_;
+            # my ($parser, $element, %attrs) = @_;
 
             $_leaf = 1;  # believe we're a leaf node until we see an end
 
@@ -171,6 +171,8 @@ sub _initialize {
                 $current = bless \$o, $_class;
             }
 
+            $current->attr({ @_[2..$#_] }) if (@_ > 2);
+
             $depth++;
             return;
         },
@@ -292,8 +294,8 @@ the same terms as perl itself
 
  $Id: $
 
- $LastChangedDate: 2007-12-24 11:23:52 +0100 (Mo, 24 Dez 2007) $
- $LastChangedRevision: 477 $
+ $LastChangedDate: 2008-01-19 13:57:57 +0100 (Sa, 19 Jan 2008) $
+ $LastChangedRevision: 497 $
  $LastChangedBy: kutterma $
 
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/MessageParser.pm $
