@@ -2,6 +2,8 @@ package SOAP::WSDL::TypeLookup;
 use strict;
 use warnings;
 
+our $VERSION=q{2.00_29};
+
 my %TYPES = (
     # wsdl:
     'http://schemas.xmlsoap.org/wsdl/' => {
@@ -86,7 +88,8 @@ my %TYPES = (
             class => 'SOAP::WSDL::XSD::Schema',
         },
         attribute => {
-            type => 'SKIP'      # not implemented yet
+            type => 'CLASS',
+            class => 'SOAP::WSDL::XSD::Attribute'      # not implemented yet
         },
         attributeGroup => {
             type => 'SKIP',     # not implemented yet
