@@ -3,12 +3,10 @@ use strict;
 use warnings;
 use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);
 
-use version; our $VERSION = qv('2.00.10');
-
 sub serialize {
     # we work on @_ for performance.
-    # $_[1] ||= {};                                   # $option_ref
-    # TODO: What about namespaces?
+    $_[1] ||= {};                                   # $option_ref
+
     return ${ $_[0]->_serialize({ attr => 1 }) };
 }
 
