@@ -9,7 +9,7 @@ require Class::Std::Fast::Storable;
 
 use base qw(SOAP::WSDL::XSD::Typelib::Builtin::anyType);
 
-our $VERSION = '2.00_27';
+our $VERSION = '2.00_29';
 
 my %ELEMENTS_FROM;
 my %ATTRIBUTES_OF;
@@ -39,6 +39,26 @@ sub AUTOMETHOD {
         . "\n"
 }
 
+# Attribute handling
+my %xml_attr_of :ATTR();
+
+sub attr {
+    my $self = shift;
+    my $class = ref $self;
+    die "$class has no attributes" if not defined %{ "$class\::_ATTR::"};
+    if (@_) {
+        # setter
+        return $xml_attr_of{ $$self } = "$class\::_ATTR"->new(@_);
+    }
+    return $xml_attr_of{ $$self } if exists $xml_attr_of{ $$self };
+    return $xml_attr_of{ $$self } = "$class\::_ATTR"->new();
+}
+
+sub serialize_attr {
+    return q{} if not $xml_attr_of{ ${ $_[0] } };
+    $_[0]->attr()->serialize();
+}
+
 sub as_hash_ref {
     my $self = shift;
     my $attributes_ref = $ATTRIBUTES_OF{ ref $self };
@@ -128,6 +148,10 @@ sub _factory {
         #     lists but don't do yet - oh my !
 
         *{ "$class\::set_$name" } = sub {
+            if (not $#_) {
+                delete $attribute_ref->{ ${ $_[0] } };
+                return;
+            };
             my $is_ref = ref $_[1];
             $attribute_ref->{ ${ $_[0] } } = ($is_ref)
                 ? ($is_ref eq 'ARRAY')
@@ -177,10 +201,6 @@ sub _factory {
             push @{ $attribute_ref->{ ${ $_[0]} } }, $_[1];
             return;
         };
-
-        # TODO: remove this alias - we don't use it, and it's pretty much
-        # misleading...
-        *{ "$class\::$name" } = *{ "$class\::add_$name" };
     }
 
     # TODO Could be moved as normal method into base class, e.g. here.
@@ -202,7 +222,7 @@ sub _factory {
            }
            : $_ =~ m{ \A              # beginning of string
                       xmlns           # xmlns
-                }xms
+                }xms        # get_elements is inlined for performance.
                 ? do {}
                 : do { use Data::Dumper;
                      croak "unknown field $_ in $class. Valid fields are:\n"
@@ -212,23 +232,25 @@ sub _factory {
         return $self;
     };
 
-
-    # this serialize method works fine for <all> and <sequence>
+    # this _serialize method works fine for <all> and <sequence>
     # complextypes, as well as for <restriction><all> or
-    # <restriction><sequence>.
+    # <restriction><sequence>, and attribute sets.
+    #
     # But what about choice, extension ?
+    #
+    # Triggers XML attribute serialization if the options hash ref contains
+    # a attr element with a true value.
     *{ "$class\::_serialize" } = sub {
         my $ident = ${ $_[0]};
+        my $option_ref = $_[1];
         # return concatenated return value of serialize call of all
         # elements retrieved from get_elements expanding list refs.
-        # get_elements is inlined for performance.
-        return join q{} , map {
+        return \join q{} , map {
             my $element = $ATTRIBUTES_OF{ $class }->{ $_ }->{ $ident };
 
             # do we have some content
             if (defined $element) {
-                $element = [ $element ]
-                    if not ref $element eq 'ARRAY';
+                $element = [ $element ] if not ref $element eq 'ARRAY';
                 my $name = $_;
 
                 map {
@@ -240,9 +262,9 @@ sub _factory {
                     # serialize complextype elments (of other types) with their
                     # serializer, but add element tags around.
                     else {
-                        join q{}, $_->start_tag({ name => $name })
+                        join q{}, $_->start_tag({ name => $name , %{ $option_ref } })
                             , $_->serialize()
-                            , $_->end_tag({ name => $name });
+                            , $_->end_tag({ name => $name , %{ $option_ref } });
                     }
                 } @{ $element }
             }
@@ -251,17 +273,20 @@ sub _factory {
             }
         } (@{ $ELEMENTS_FROM{ $class } });
     };
+}
 
-    *{ "$class\::serialize" } = sub {
-            $_[1] ||= {};   # maybe even replace by assigning a constant var
+sub serialize {
+    # we work on @_ for performance.
+    $_[1] ||= {};                                   # $option_ref
 
-            # do we have a empty element ?
-            return $_[0]->start_tag({ %{ $_[1] }, empty => 1 })
-                if not defined $ELEMENTS_FROM{ $class } or not @{ $ELEMENTS_FROM{ $class } };
-            return join q{}, $_[0]->start_tag($_[1]),
-                    $_[0]->_serialize(), $_[0]->end_tag();
-    }
+    # get content first (pass by reference to avoid copying)
+    my $content_ref = $_[0]->_serialize($_[1]);     # option_ref
 
+    # do we have a empty element ?
+    return $_[0]->start_tag({ %{ $_[1] }, empty => 1 })
+        if not length ${ $content_ref };
+
+    return join q{}, $_[0]->start_tag($_[1]), ${ $content_ref }, $_[0]->end_tag();
 }
 
 1;
@@ -281,24 +306,24 @@ To subclass, write a package like this:
  package MyComplexType;
  use Class::Std::Fast::Storable constructor => 'none';
  use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);
- 
+
  # we only need the :get attribute qualifier.
  # set and init_arg are automatically created by
  # SOAP::WSDL::XSD::Typelib::ComplexType
  my %first_attr_of   :ATTR(:get<first_attr>  :default<()>);
  my %second_attr_of  :ATTR(:get<second_attr> :default<()>);
  my %third_attr_of   :ATTR(:get<third_attr>  :default<()>);
- 
+
  # the order of elements in a complexType
  my @elements_from = qw(first_attr second_attr third_attr);
- 
+
  # references to the private hashes
  my %attribute_of = (
     first_attr  => \%first_attr_of,
     second_attr => \%second_attr_of,
     third_attr  => \%third_attr_of,
  );
- 
+
  # classes_of: Classes the child elements should be of
  my %classes_of = (
     first_attr  => 'My::FirstElement',
@@ -339,14 +364,14 @@ complain, too.
 Examples:
 
  my $obj = MyClass->new({ MyName => $value });
- 
+
  my $obj = MyClass->new({
      MyName => {
          DeepName => $value,
      },
      MySecondName => $value,
  });
- 
+
  my $obj = MyClass->new({
      MyName => [
         { DeepName => $value },
@@ -380,6 +405,13 @@ This means you may set element properties by passing
 
 Examples are similar to the examples provided for new() above.
 
+Note that you cannot delete a property by setting it to undef - this sets
+the property to a empty property object (with vaue undef).
+
+To delete a property, say
+
+ $obj->set_FOO();
+
 =head2 as_hash_ref
 
 Returns a hash ref representation of the complexType object
@@ -423,9 +455,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 477 $
+ $Rev: 497 $
  $LastChangedBy: kutterma $
- $Id: ComplexType.pm 477 2007-12-24 10:23:52Z kutterma $
+ $Id: ComplexType.pm 497 2008-01-19 12:57:57Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/ComplexType.pm $
 
 =cut
