@@ -116,15 +116,23 @@ No facets are implemented yet.
 
 =back
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2004-2007 Martin Kutter.
+
+This file is part of SOAP-WSDL. You may distribute/modify it under the same
+terms as perl itself
+
 =head1 AUTHOR
 
-Replace whitespace by @ in e-mail address.
+Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
- Martin Kutter E<gt>martin.kutter fen-net.deE<lt>
+=head1 REPOSITORY INFORMATION
 
-=head1 COPYING
-
-This library is free software, you may distribute/modify it under the
-same terms as perl itself
+ $Rev: 477 $
+ $LastChangedBy: kutterma $
+ $Id: SimpleType.pm 477 2007-12-24 10:23:52Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/SimpleType.pm $
 
 =cut
+
